A direct object reference occurs when an Application exposes a direct
reference to an internal object without proper authorization.

This class of vulnerability results in an insecure direct, which may
result in access to sensitive data and authorization bypass.
